﻿using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;

namespace BestFitPanelSL
{
    public partial class MainPage : UserControl
    {
        private readonly Brush _borderBrush = new SolidColorBrush(Colors.Transparent);
        private readonly Dictionary<Panel, Brush> _backgrounds = new Dictionary<Panel, Brush>();

        public MainPage()
        {
            InitializeComponent();
            _backgrounds.Add(MostBig, new SolidColorBrush(Color.FromArgb(0x40, 0xff, 0x00, 0x00)));
            _backgrounds.Add(MostFull, new SolidColorBrush(Color.FromArgb(0x40, 0xff, 0x00, 0xff)));
            _backgrounds.Add(MostSquare, new SolidColorBrush(Color.FromArgb(0x40, 0x00, 0xff, 0x00)));
            _backgrounds.Add(MostGolden, new SolidColorBrush(Color.FromArgb(0x40, 0x00, 0x00, 0xff)));
            ElementCountComboBox.SelectedIndex = 3;
        }

        private void PanelVisibilityCheckBoxClick(object sender, RoutedEventArgs e)
        {
            // Toggle visibility on the corresponding Panel
            ((Panel)(((FrameworkElement)sender).Tag)).Visibility = ((CheckBox)sender).IsChecked.GetValueOrDefault() ? Visibility.Visible : Visibility.Collapsed;
        }

        private void ElementCountSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            // Update the number of elements in each Panel
            var elementCount = e.AddedItems.OfType<int>().Single();
            PopulatePanels(elementCount);
        }

        private void PopulatePanels(int elementCount)
        {
            // Populate each panel with the specified number of elements
            foreach (var panel in new Panel[] { MostBig, MostFull, MostSquare, MostGolden })
            {
                panel.Children.Clear();
                for (var i = 0; i < elementCount; i++)
                {
                    panel.Children.Add(
                        new Border
                        {
                            Background = _backgrounds[panel],
                            BorderBrush = _borderBrush,
                            BorderThickness = new Thickness(2),
#if !SILVERLIGHT
                            SnapsToDevicePixels = true,
#endif
                        });
                }
            }
        }
    }
}
